<?php
/*
 * This file is part of pluck, the easy content management system
 * Copyright (c) somp (www.somp.nl)
 * http://www.pluck-cms.org

 * Pluck is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * See docs/COPYING for the complete license.
*/

//First define that we are in pluck.
define('IN_PLUCK', true);

//Then start session support.
session_start();

//Include security-enhancements
require_once('data/inc/security.php');
//Include functions
require_once('data/inc/functions.all.php');
require_once('data/inc/functions.admin.php');
//Include variables
require_once('data/inc/variables.all.php');

//First check if we've installed pluck
if (!file_exists('data/settings/install.dat')) {
	$titelkop = $lang_error1;
	include_once('data/inc/header2.php');
	redirect('install.php', '3');
	echo $lang_login2;
	include_once('data/inc/footer.php');
}

else {
	//Then check if we are properly logged in
	require_once ('data/settings/token.php');
	if (!isset($_SESSION[$token]) || ($_SESSION[$token] != 'pluck_loggedin')) {
		$titelkop = $lang_error3;
		include_once('data/inc/header2.php');
		redirect('login.php', '3', 1);
		echo $lang_error4;
		include_once('data/inc/footer.php');
		exit;
	}

	//Check for required session id (to prevent CSRF)
	if ((!isset($_GET['s'])) || ($_GET['s'] != session_id()))
		die('Cross-site request forgery detected.');

	//Include proper POST/GETs
	require_once('data/inc/post_get.php');

	//Define pages
	//------------
	if($action) {
		switch ($action)
		{
			//Page:Start
			case 'start':
				$titelkop = $lang_kop1;
				include_once('data/inc/header.php');
				include_once('data/inc/start.php');
				break;

			//Page:Credits
			case 'credits':
				$titelkop = $lang_credits;
				include_once('data/inc/header.php');
				include_once('data/inc/credits.php');
				break;

			//Page:Pages
			case 'page':
				$titelkop = $lang_kop2;
				include_once('data/inc/header.php');
				include_once('data/inc/page.php');
				break;

			//Page:New Page
			case 'newpage':
				$tinymce = 'yes';
				$titelkop = $lang_kop11;
				include_once('data/inc/header.php');
				include_once('data/inc/newpage.php');
				break;

			//Page:Manage Images
			case 'images':
				$titelkop = $lang_kop17;
				include_once('data/inc/header.php');
				include_once('data/inc/images.php');
				break;

			//Page:Modules
			case 'modules':
				$titelkop = $lang_modules;
				include_once('data/inc/header.php');
				include_once('data/inc/modules.php');
				break;

			//Page:Manage Modules
			case 'managemodules':
				$titelkop = $lang_modules3;
				include_once('data/inc/header.php');
				include_once('data/inc/modules_manage.php');
				break;

			//Page:Module Add To Site
			case 'module_addtosite':
				$titelkop = $lang_modules14;
				include_once('data/inc/header.php');
				include_once('data/inc/modules_manage_addtosite.php');
				break;

			//Page:Options
			case 'options':
				$titelkop = $lang_kop4;
				include_once('data/inc/header.php');
				include_once('data/inc/options.php');
				break;

			//Page:Options:Settings
			case 'settings':
				$titelkop = $lang_settings;
				include_once('data/inc/header.php');
				include_once('data/inc/settings.php');
				break;

			//Page:Options:Language
			case 'language':
				$titelkop = $lang_kop14;
				include_once('data/inc/header.php');
				include_once('data/inc/language.php');
				break;

			//Page:Options:Theme
			case 'theme':
				$titelkop = $lang_kop16;
				include_once('data/inc/header.php');
				include_once('data/inc/theme.php');
				break;

			//Page:Options:Changepass
			case 'changepass':
				$titelkop = $lang_kop10;
				include_once('data/inc/header.php');
				include_once('data/inc/changepass.php');
				break;

			//Page:Options:Themeinstall
			case 'themeinstall':
				$titelkop = $lang_theme5;
				include_once('data/inc/header.php');
				include_once('data/inc/themeinstall.php');
				break;

			//Page:Options:Moduleinstall
			case 'installmodule':
				$titelkop = $lang_modules23;
				include_once('data/inc/header.php');
				include_once('data/inc/modules_install.php');
				break;

			//Page:Trashcan
			case 'trashcan':
				$titelkop = $lang_trash;
				include_once('data/inc/header.php');
				include_once('data/inc/trashcan.php');
				break;

			//Page:Empty Trashcan
			case 'trashcan_empty':
				$titelkop = $lang_trash;
				include_once('data/inc/header.php');
				include_once('data/inc/trashcan_empty.php');
				break;

			//Page:Logout
			case 'logout':
				// Unset all of the session variables.
				$_SESSION = array();
				// If it's desired to kill the session, also delete the session cookie.
				// Note: This will destroy the session, and not just the session data!
				if (ini_get('session.use_cookies')) {
					$params = session_get_cookie_params();
					setcookie(session_name(), '', time() - 42000,
						$params['path'], $params['domain'],
						$params['secure'], $params['httponly']
					);
				}
				// Finally, destroy the session.
				session_destroy();
				//Redirect and stop code execution
				redirect('index.php', '0', 1);
				exit;
				break;

			//Page:Uninstall module
			case 'module_delete':
				$titelkop = $lang_modules10;
				include_once('data/inc/header.php');
				include_once('data/inc/modules_manage_delete.php');
				break;

			//Unknown page => Redirect
			default:
				header('Location: ?action=start');
				exit;
				break;
		}
	}


	//Editpage pages
	elseif($editpage) {
		$tinymce = 'yes';
		$titelkop = $lang_page3;
		include_once('data/inc/header.php');
		include_once('data/inc/editpage.php');
	}

	//Editmeta pages
	elseif($editmeta) {
		$titelkop = $lang_meta1;
		include_once('data/inc/header.php');
		include_once('data/inc/page_editmeta.php');
	}

	//Deletepage pages
	elseif($deletepage) {
		$titelkop = $lang_trash1;
		include_once('data/inc/header.php');
		echo $lang_trash2;
		include_once('data/inc/deletepage.php');
	}

	//Deleteimage pages
	elseif($deleteimage) {
		$titelkop = $lang_trash1;
		include_once('data/inc/header.php');
		echo $lang_trash2;
		include_once('data/inc/deleteimage.php');
	}

	//Pageup pages
	elseif($pageup) {
		$titelkop = $lang_updown1;
		include_once('data/inc/header.php');
		include_once('data/inc/pageup.php');
	}

	//Pagedown pages
	elseif($pagedown) {
		$titelkop = $lang_updown1;
		include_once('data/inc/header.php');
		include_once('data/inc/pagedown.php');
	}

	//Trash_viewitem pages
	elseif($trash_viewitem) {
		$titelkop = $lang_trash7;
		include_once('data/inc/header.php');
		include_once('data/inc/trashcan_viewitem.php');
	}

	//Trash_restoreitem pages
	elseif($trash_restoreitem) {
		$titelkop = $lang_trash10;
		include_once('data/inc/header.php');
		include_once('data/inc/trashcan_restoreitem.php');
	}

	//Trash_deleteitem pages
	elseif($trash_deleteitem) {
		$titelkop = $lang_trash8;
		include_once('data/inc/header.php');
		include_once('data/inc/trashcan_deleteitem.php');
	}

	//Unknown pages
	else {
	if ((!$modulestart) && (!$module)) {
		header('Location: ?action=start');
		exit;
		}
	}

	//Include module pages
	include_once('data/inc/modules_admininclude.php');

	//Include footer
	include_once('data/inc/footer.php');
}
?>
